.. title:: Overview

Welcome to the docs
===================

Contents
	* :ref:`intro`: Introduction & Installation
	* :ref:`examples`: Code examples
	* :ref:`codedoc`: The code documentation of FermiLib.

.. toctree::
	:maxdepth: 2
	:hidden:

	intro
	examples
	fermilib

